Crate snake_helper

Crate snake_helper 

A crate providing helper macros

Macros

into_none_if
Into None If
or_wrap_err
Turn an option into an Result with the given error message. If you get an error saying trait bound not satified make sure the first argument is an Option.
unwrap_err_or
unwrap_none_or
unwrap_ok_or
unwrap_or_print_err
Unwrap or print
unwrap_some_or
wrap_err
Turns Error into an Diagnostic and wraps it with the specified error