A crate providing helper macros
Macros
- into_
none_ if - Into None If
- or_
wrap_ err - Turn an option into an Result with the given error message. If you get an error saying trait bound not satified make sure the first argument is an Option.
- unwrap_
err_ or - unwrap_
none_ or - unwrap_
ok_ or - unwrap_
or_ print_ err - Unwrap or print
- unwrap_
some_ or - wrap_
err - Turns Error into an Diagnostic and wraps it with the specified error